Installation — pysal v25.7rc1 Manual

Skip to main content
`Ctrl`+`K`

# Installation

You can install the meta package pysal which results in all the packages in the pysal ecosystem being installed.

Alternatively, individual packages can be installed a la carte.

## Installing the pysal meta package

PIP

    pip install pysal

CONDA

    conda install --channel conda-forge pysal

## Installing individual pysal packages

A similar approach can be used to select one, or a subset, of pysal packages without having to install the entire ecosystem. For example, to install esda and mapclassify

PIP

    pip install esda mapclassify

CONDA

    conda install --channel conda-forge esda mapclassify

## Installing the development version

Potentially, you might want to use the newest features in the development version of PySAL on github - pysal/pysal while have not been incorporated in the Pypi released version. You can achieve that by installing pysal/pysal by running the following from a command shell:

    pip install git+https://github.com/pysal/pysal.git

You can also fork the pysal/pysal repo and create a local clone of your fork. By making changes to your local clone and submitting a pull request to pysal/PySAL, you can contribute to the PySAL development.

## Dependencies

### Required

- geopandas

- seaborn

- descartes

- palettable

- scikit-learn

- rtree

- tqdm

- statsmodels

- deprecated

### Optional

- urbanaccess

- pandana

- numba

- numexpr

- bokeh

## Installing versions supporting Python 2

Users requiring Python 2 support can install the legacy version of PySAL: 1.1.14 via pip:

    pip install pysal==1.14.4.post2

Note that this version is only receiving bug fixes. All new enhancements (post 2019-01) to PySAL are Python 3+ only, and are not available in 1.14.4.